// ===========================================================================
// CONTENT  : CLASS NodeSpy
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 26/02/2003
// HISTORY  :
//  22/09/2002  duma  CREATED
//	26/02/2003	duma	changed	-> Removed static code to register NodeRenderer
//
// Copyright (c) 2002-2003, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.joi.xml ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pf.joi.AbstractObjectSpy;
import org.pf.joi.ElementSpy;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * This spy provides inspection of org.w3c.dom.Node objects.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
class NodeSpy extends AbstractObjectSpy
{
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public NodeSpy( Object obj )
  {
    super( obj ) ;
  } // NodeSpy()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

	protected String getString()
	{
		String str = "" ;
		
		switch ( this.getNode().getNodeType() )
		{
			case Node.ELEMENT_NODE :
				str = "<" + this.getNode().getNodeName() + ">" ;
				break ;
			case Node.ATTRIBUTE_NODE :
				str = "@" + this.getNode().getNodeName() ;
				break ;
			default :
				str = this.getNode().getNodeName() ; 
		}
		return str ;
	} // getString()

  // -------------------------------------------------------------------------

  protected void addAllElements()
    throws SecurityException
  {
  	this.addAttributes() ;
  	this.addChildren() ;
  } // addAllElements()

  // -------------------------------------------------------------------------

	protected void addChildren()
	{
    NodeList children ;
    Node node ;

    children = this.getNode().getChildNodes() ;
    for ( int index = 0 ; index < children.getLength() ; index++ )
    {
    	node = children.item( index ) ;
    	if ( ! this.isWhitespaceNode( node ) )
    	{
      	this.addNode( node ) ;
    	}
    }
	} // addChildren()

	// -------------------------------------------------------------------------
	
	protected void addAttributes()
	{
    Node node ;
    NamedNodeMap attributes ;

    attributes = this.getNode().getAttributes() ;
    if ( attributes != null )
    {
	    for ( int index = 0 ; index < attributes.getLength() ; index++ )
	    {
	    	node = attributes.item( index ) ;
	    	this.addNode( node ) ;
	    }
    }		
	} // addAttributes()

	// -------------------------------------------------------------------------
	
	protected void addNode( Node node )
	{
		ElementSpy elementSpy ;
		
		elementSpy = new NodeElementSpy( this, node ) ;
    this.getElementHolders().add( elementSpy ) ;
	} // addNode()

	// -------------------------------------------------------------------------

	protected boolean isWhitespaceNode( Node node )
	{
		String text ;
		
		if ( node.getNodeType() == Node.TEXT_NODE )
		{
			text = node.getNodeValue() ;
			if ( ( text == null ) || ( text.trim().length() == 0 ) )
				return true ;
		}
		return false ;
	} // isWhitespaceNode()

	// -------------------------------------------------------------------------
	protected Node getNode()
	{
		return (Node)this.getObject() ;
	} // getNode()

	// -------------------------------------------------------------------------
	
} // class NodeSpy