// ===========================================================================
// CONTENT  : TEST CLASS XMLObjectExporterTest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 14/06/2001
// HISTORY  :
//  14/06/2001  duma  CREATED
//
// Copyright (c) 2001, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.joi.xml;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.File;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.jaxen.XPath;
import org.jaxen.dom.DOMXPath;
import org.pf.joi.ExportProvider;
import org.pf.joi.ObjectSpy;
import org.pf.six.XmlStreamReader;
import org.w3c.dom.Document;

/**
 * Test class for corresponding business class.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class XMLObjectExporterTest extends TestCase
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public XMLObjectExporterTest( String name )
  {
    super( name ) ;
  } // XMLObjectExporterTest()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public static Test suite()
  {
		return new TestSuite( XMLObjectExporterTest.class ) ;
	} // suite()

  // =========================================================================
  // TEST METHODS
  // =========================================================================

  public void test_Export_1()
    	throws Exception
  {
    ExportProvider exporter       = null ;
    String inspectedObject        = "Neptun" ;
    File file                     = null ;
    ObjectSpy spy                 = new ObjectSpy( inspectedObject ) ;

    file = new File( System.getProperty( "user.home" ), "test1.xml" ) ;
    try { file.delete() ; } catch ( Exception ex ) {} ;

    exporter = new XMLObjectExporter() ;
    this.assertTrue( exporter.export( spy, file.getAbsolutePath() ) ) ;
    this.assertTrue( file.getAbsolutePath() + " not found!" , file.exists() );
  } // test_Export_1()

  // -------------------------------------------------------------------------

  public void test_Export_2()
  	throws Exception
  {
    ExportProvider exporter       = null ;
    String inspectedObject        = "Cassiopeia" ;
    File file                     = null ;
    ObjectSpy spy                 = new ObjectSpy( inspectedObject ) ;
		XPath	xPath 									= null ;
		Document doc 									= null ;
		String value ;

    file = new File( System.getProperty( "user.home" ), "extest1.xml" ) ;
    try { file.delete() ; } catch ( Exception ex ) {} ;

    exporter = new XMLObjectExporter() ;
    this.assertTrue( exporter.export( spy, file.getAbsolutePath() ) ) ;
    this.assertTrue( "Must exist", file.exists() ) ;

		doc = XmlStreamReader.readDOM( file, false ) ;		
		assertNotNull( doc ) ;

		xPath = new DOMXPath( "/JOI/InspectedObject/Type/Modifier[1]/@name" ) ;
		value = xPath.stringValueOf( doc ) ;
		assertEquals( "public", value ) ;

		xPath = new DOMXPath( "/JOI/InspectedObject/Object/DisplayValue" ) ;
		value = xPath.stringValueOf( doc ) ;
		assertEquals( inspectedObject, value ) ;

		xPath = new DOMXPath( "/JOI/InspectedObject/Object/Element[@name='count']/Object/DisplayValue" ) ;
		value = xPath.stringValueOf( doc ) ;
		assertEquals( "10", value ) ;
  } // test_Export_2()

  // -------------------------------------------------------------------------


  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected void setUp()
  	throws Exception
  {
  	super.setUp() ;
	} // setUp()

	// -------------------------------------------------------------------------

	protected XPath parseXPath( String xPathStr )
		throws Exception
	{
		XPath	xPath = null ;

		xPath = new DOMXPath( xPathStr ) ;
		return xPath ;
	} // parseXPath()

	// -------------------------------------------------------------------------

} // class XMLObjectExporterTest